summaryrefslogtreecommitdiffstats
path: root/src/entryeditdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryeditdialog.h')
-rw-r--r--src/entryeditdialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/entryeditdialog.h b/src/entryeditdialog.h
index 7dafffd..e645b81 100644
--- a/src/entryeditdialog.h
+++ b/src/entryeditdialog.h
@@ -39,7 +39,7 @@ Q_OBJECT
friend class GUI::FieldWidget;
public:
- EntryEditDialog(TQWidget* tqparent, const char* name);
+ EntryEditDialog(TQWidget* parent, const char* name);
/**
* Checks to see if any data needs to be saved. Returns @p true if it's ok to continue with
@@ -75,7 +75,7 @@ public:
* Updates a widget when its field has been modified. The category may have changed, completions may have
* been added or removed, or what-have-you.
*
* @param coll A pointer to the tqparent collection
* @param oldField A pointer to the old field, which should have the same name as the new one
* @param newField A pointer to the new field
*/
@@ -75,7 +75,7 @@ public:
* been added or removed, or what-have-you.
*
- * @param coll A pointer to the tqparent collection
+ * @param coll A pointer to the parent collection
* @param oldField A pointer to the old field, which should have the same name as the new one
* @param newField A pointer to the new field